@@ -27,7 +27,13 @@ class BotConfig:
         event_logging_enabled (bool): Whether to enable event logging. Defaults to True.
         max_logged_events (int): The maximum number of events to log. Defaults to 1000.
         event_middleware_enabled (bool): Whether to enable event middleware. Defaults to True.
-    announce_enabled (bool): Whether to enable bot announcements. Defaults to True.
+        announce_enabled (bool): Whether to enable bot announcements. Defaults to True.
+        signature_verification_enabled (bool): Whether to enable cryptographic signature verification for incoming messages. Defaults to False.
+        require_message_signatures (bool): Whether to reject unsigned messages when signature verification is enabled. Defaults to False.
+        stamp_cost (int): The cost of stamps for outgoing messages. None disables stamps. Defaults to None.
+        direct_delivery_retries (int): Number of times to retry direct delivery before falling back to propagation. Defaults to 3.
+        propagation_fallback_enabled (bool): Whether to use propagation nodes as fallback after direct delivery fails. Defaults to True.
+        test_mode (bool): Whether to run in test mode (skips RNS initialization). Defaults to False.
 
     """
 
@@ -51,6 +57,12 @@ class BotConfig:
     max_logged_events: int = 1000
     event_middleware_enabled: bool = True
     announce_enabled: bool = True
+    signature_verification_enabled: bool = False
+    require_message_signatures: bool = False
+    stamp_cost: int = None
+    direct_delivery_retries: int = 3
+    propagation_fallback_enabled: bool = True
+    test_mode: bool = False
 
     def __post_init__(self):
         """Post-initialization to ensure admins is a set."""
@@ -59,4 +71,4 @@ class BotConfig:
 
     def __str__(self):
         """Return a string representation of the BotConfig object."""
-        return f"BotConfig(name={self.name}, announce={self.announce}, announce_immediately={self.announce_immediately}, admins={self.admins}, hot_reloading={self.hot_reloading}, rate_limit={self.rate_limit}, cooldown={self.cooldown}, max_warnings={self.max_warnings}, warning_timeout={self.warning_timeout}, command_prefix={self.command_prefix}, cogs_dir={self.cogs_dir}, cogs_enabled={self.cogs_enabled}, permissions_enabled={self.permissions_enabled}, storage_type={self.storage_type}, storage_path={self.storage_path}, first_message_enabled={self.first_message_enabled}, event_logging_enabled={self.event_logging_enabled}, max_logged_events={self.max_logged_events}, event_middleware_enabled={self.event_middleware_enabled}, announce_enabled={self.announce_enabled})"
+        return f"BotConfig(name={self.name}, announce={self.announce}, announce_immediately={self.announce_immediately}, admins={self.admins}, hot_reloading={self.hot_reloading}, rate_limit={self.rate_limit}, cooldown={self.cooldown}, max_warnings={self.max_warnings}, warning_timeout={self.warning_timeout}, command_prefix={self.command_prefix}, cogs_dir={self.cogs_dir}, cogs_enabled={self.cogs_enabled}, permissions_enabled={self.permissions_enabled}, storage_type={self.storage_type}, storage_path={self.storage_path}, first_message_enabled={self.first_message_enabled}, event_logging_enabled={self.event_logging_enabled}, max_logged_events={self.max_logged_events}, event_middleware_enabled={self.event_middleware_enabled}, announce_enabled={self.announce_enabled}, signature_verification_enabled={self.signature_verification_enabled}, require_message_signatures={self.require_message_signatures}, test_mode={self.test_mode})"
