@@ -15,7 +15,6 @@ import time
 from concurrent.futures import ThreadPoolExecutor
 from queue import Queue
 from types import SimpleNamespace
-from typing import Optional
 
 import RNS
 from LXMF import LXMessage, LXMRouter
@@ -29,6 +28,8 @@ from .help import HelpSystem
 from .middleware import MiddlewareContext, MiddlewareManager, MiddlewareType
 from .moderation import SpamProtection
 from .permissions import DefaultPerms, PermissionManager
+from .scheduler import TaskScheduler
+from .signatures import SignatureManager, sign_outgoing_message, verify_incoming_message
 from .storage import JSONStorage, SQLiteStorage
 from .transport import Transport
 from .validation import format_validation_results, validate_bot
@@ -56,12 +57,17 @@ class LXMFBot:
         self.commands = {}
         self.cogs = {}
         self.first_message_handlers = []
+        self.message_handlers = []
         self.delivery_callbacks = []
         self.receipts = []
-        self.queue = Queue(maxsize=5) # Outbound LXMF message queue
+        self.queue = Queue(maxsize=5)  # Outbound LXMF message queue
+        self.delivery_attempts = {}  # Track delivery attempts per destination
         self.announce_time = 600
         self.logger = logging.getLogger(__name__)
-        self.thread_pool = ThreadPoolExecutor(max_workers=5) # For offloading CPU-bound or blocking I/O tasks
+        self.thread_pool = ThreadPoolExecutor(
+            max_workers=5,
+        )  # For offloading CPU-bound or blocking I/O tasks
+        self.scheduler = TaskScheduler(self)  # Initialize the scheduler
 
         self.config_path = os.path.join(os.getcwd(), "config")
         os.makedirs(self.config_path, exist_ok=True)
@@ -73,7 +79,7 @@ class LXMFBot:
 
         self.permissions = PermissionManager(
             storage=self.storage,
-            enabled=self.config.permissions_enabled
+            enabled=self.config.permissions_enabled,
         )
 
         self.events = EventManager(self.storage)
@@ -89,7 +95,7 @@ class LXMFBot:
         if not os.path.exists(init_file):
             open(init_file, "w", encoding="utf-8").close()
 
-        self.transport = Transport(self)
+        self.transport = Transport(self.storage)
         self.spam_protection = SpamProtection(
             storage=self.storage,
             bot=self,
@@ -99,35 +105,56 @@ class LXMFBot:
             warning_timeout=self.config.warning_timeout,
         )
 
-        identity_file = os.path.join(self.config_path, "identity")
-        if not os.path.isfile(identity_file):
-            RNS.log("No Primary Identity file found, creating new...", RNS.LOG_INFO)
-            identity = RNS.Identity(True)
-            identity.to_file(identity_file)
-        self.identity = RNS.Identity.from_file(identity_file)
-        RNS.log("Loaded identity from file", RNS.LOG_INFO)
+        if not self.config.test_mode:
+            identity_file = os.path.join(self.config_path, "identity")
+            if not os.path.isfile(identity_file):
+                RNS.log("No Primary Identity file found, creating new...", RNS.LOG_INFO)
+                identity = RNS.Identity(True)
+                identity.to_file(identity_file)
+            self.identity = RNS.Identity.from_file(identity_file)
+            RNS.log("Loaded identity from file", RNS.LOG_INFO)
 
-        RNS.Reticulum(loglevel=RNS.LOG_VERBOSE)
-        self.router = LXMRouter(identity=self.identity, storagepath=self.config_path)
-        self.local = self.router.register_delivery_identity(
-            self.identity, display_name=self.config.name
-        )
-        self.router.register_delivery_callback(self._message_received)
-        RNS.log(
-            f"LXMF Router ready to receive on: {RNS.prettyhexrep(self.local.hash)}",
-            RNS.LOG_INFO,
-        )
+            # Initialize Reticulum (will raise exception if already running)
+            try:
+                RNS.Reticulum(loglevel=RNS.LOG_VERBOSE)
+            except OSError as e:
+                if "reinitialise" in str(e).lower():
+                    # Reticulum already running, continue
+                    pass
+                else:
+                    raise
+            self.router = LXMRouter(
+                identity=self.identity, storagepath=self.config_path,
+            )
+            self.local = self.router.register_delivery_identity(
+                self.identity,
+                display_name=self.config.name,
+            )
+            self.router.register_delivery_callback(self._message_received)
+            RNS.log(
+                f"LXMF Router ready to receive on: {RNS.prettyhexrep(self.local.hash)}",
+                RNS.LOG_INFO,
+            )
+        else:
+            # Test mode - create mock components
+            self.identity = RNS.Identity()  # Create a basic identity for testing
+            self.router = None
+            self.local = None
 
         self.announce_enabled = self.config.announce_enabled
         self.announce_time = self.config.announce
 
-        if self.config.announce_immediately and self.announce_enabled:
-            announce_file = os.path.join(self.config_path, "announce")
-            if os.path.isfile(announce_file):
-                os.remove(announce_file)
-                RNS.log("Announcing now. Timer reset.", RNS.LOG_INFO)
-            self.local.announce()
-            RNS.log("Initial announce sent", RNS.LOG_INFO)
+        if self.announce_enabled and not self.config.test_mode:
+            # Schedule the announce task
+            self.scheduler.add_task(
+                "announce_task",
+                self._announce,
+                f"*/{self.announce_time // 60} * * * *",  # Convert seconds to minutes for cron
+            )
+            if self.config.announce_immediately:
+                # Force an immediate announce if configured
+                self._announce()
+                RNS.log("Initial announce sent", RNS.LOG_INFO)
 
         self.admins = set(self.config.admins or [])
         self.hot_reloading = self.config.hot_reloading
@@ -135,6 +162,12 @@ class LXMFBot:
 
         self.help_system = HelpSystem(self)
 
+        self.signature_manager = SignatureManager(
+            self,
+            verification_enabled=self.config.signature_verification_enabled,
+            require_signatures=self.config.require_message_signatures,
+        )
+
         if self.config.cogs_enabled:
             load_cogs_from_directory(self)
 
@@ -146,9 +179,9 @@ class LXMFBot:
             **kwargs: Command attributes (name, description, admin_only).
 
         """
+
         def decorator(func):
-            """The actual decorator that registers the command.
-            """
+            """The actual decorator that registers the command."""
             name = args[0] if len(args) > 0 else kwargs.get("name", func.__name__)
 
             description = kwargs.get("description", "No description provided")
@@ -172,11 +205,11 @@ class LXMFBot:
             ImportError: If the extension is missing setup function or fails to load.
 
         """
-        if not re.match(r'^[a-zA-Z0-9_\.]+$', name):
+        if not re.match(r"^[a-zA-Z0-9_\.]+$", name):
             raise ValueError(f"Invalid module name format: {name}")
 
-        if not name.startswith('cogs.'):
-            name = f'cogs.{name}'
+        if not name.startswith("cogs."):
+            name = f"cogs.{name}"
 
         try:
             if self.hot_reloading and name in sys.modules:
@@ -188,7 +221,7 @@ class LXMFBot:
                 raise ImportError(f"Extension {name} missing setup function")
             module.setup(self)
         except ImportError as e:
-            raise ImportError(f"Failed to load extension {name}: {str(e)}") from e
+            raise ImportError(f"Failed to load extension {name}: {e!s}") from e
 
     def add_cog(self, cog):
         """Add a cog to the bot.
@@ -199,27 +232,40 @@ class LXMFBot:
         """
         self.cogs[cog.__class__.__name__] = cog
         for _name, method in inspect.getmembers(
-            cog, predicate=lambda x: hasattr(x, "command")
+            cog,
+            predicate=lambda x: hasattr(x, "command"),
         ):
-            if _name.startswith('_') or _name == 'bot':
+            if _name.startswith("_") or _name == "bot":
                 continue
 
             try:
                 cmd_descriptor = method.command
 
-                if hasattr(cmd_descriptor, '__get__') and hasattr(cmd_descriptor, 'name'):
+                if hasattr(cmd_descriptor, "__get__") and hasattr(
+                    cmd_descriptor,
+                    "name",
+                ):
                     cmd = cmd_descriptor.__get__(cog, cog.__class__)
-                elif hasattr(cmd_descriptor, 'name'):
+                elif hasattr(cmd_descriptor, "name"):
                     cmd = cmd_descriptor
                     if cmd.callback is None:
                         cmd.callback = method
                 else:
-                    self.logger.warning(f"Unexpected command type for {_name}: {type(cmd_descriptor)}")
+                    self.logger.warning(
+                        "Unexpected command type for %s: %s",
+                        _name,
+                        type(cmd_descriptor),
+                    )
                     continue
 
                 self.commands[cmd.name] = cmd
             except Exception as e:
-                self.logger.error(f"Error adding command {_name} from cog {cog.__class__.__name__}: {e}")
+                self.logger.error(
+                    "Error adding command %s from cog %s: %s",
+                    _name,
+                    cog.__class__.__name__,
+                    e,
+                )
                 continue
 
     def is_admin(self, sender):
@@ -236,6 +282,7 @@ class LXMFBot:
 
     def _register_builtin_events(self):
         """Register built-in event handlers."""
+
         @self.events.on("message_received", EventPriority.HIGHEST)
         def handle_message(event):
             """Handles incoming messages, performing spam checks."""
@@ -250,7 +297,7 @@ class LXMFBot:
     def _process_message(self, message, sender):
         """Process an incoming message."""
         try:
-            content = message.content.decode('utf-8')
+            content = message.content.decode("utf-8")
             receipt = RNS.hexrep(message.hash, delimit=False)
 
             def reply(response, **kwargs):
@@ -270,6 +317,11 @@ class LXMFBot:
             if not self.permissions.has_permission(sender, DefaultPerms.USE_BOT):
                 return
 
+            # Call message handlers
+            for handler in self.message_handlers:
+                if handler(sender, message):
+                    return
+
             msg_ctx = {
                 "lxmf": message,
                 "reply": reply,
@@ -285,7 +337,7 @@ class LXMFBot:
 
             if self.command_prefix is None or content.startswith(self.command_prefix):
                 command_name = (
-                    content.split()[0][len(self.command_prefix):]
+                    content.split()[0][len(self.command_prefix) :]
                     if self.command_prefix
                     else content.split()[0]
                 )
@@ -293,7 +345,10 @@ class LXMFBot:
                     cmd = self.commands[command_name]
 
                     if not self.permissions.has_permission(sender, cmd.permissions):
-                        self.send(sender, "You don't have permission to use this command.")
+                        self.send(
+                            sender,
+                            "You don't have permission to use this command.",
+                        )
                         return
 
                     try:
@@ -312,7 +367,11 @@ class LXMFBot:
                         return
 
                     except Exception as e:
-                        self.logger.error("Error executing command %s: %s", command_name, str(e))
+                        self.logger.error(
+                            "Error executing command %s: %s",
+                            command_name,
+                            str(e),
+                        )
                         self.send(sender, "Error executing command: %s", str(e))
                         return
 
@@ -338,7 +397,7 @@ class LXMFBot:
             event_data = {
                 "message": message,
                 "sender": sender,
-                "receipt": receipt
+                "receipt": receipt,
             }
 
             ctx = MiddlewareContext(MiddlewareType.PRE_EVENT, event_data)
@@ -349,14 +408,25 @@ class LXMFBot:
             self.events.dispatch(event)
 
             if not event.cancelled:
-                self._process_message(message, sender)
+                # Verify message signature if enabled
+                if verify_incoming_message(self, message, sender):
+                    self._process_message(message, sender)
+                else:
+                    RNS.log(
+                        f"Rejected message from {sender} due to invalid signature",
+                        RNS.LOG_WARNING,
+                    )
 
         except Exception as e:
             self.logger.error("Error handling received message: %s", str(e))
 
     def _announce(self):
         """Send an announce if the configured interval has passed."""
-        if self.announce_time == 0 or not self.announce_enabled:
+        if (
+            self.announce_time == 0
+            or not self.announce_enabled
+            or self.config.test_mode
+        ):
             RNS.log("Announcements disabled", RNS.LOG_DEBUG)
             return
 
@@ -377,9 +447,19 @@ class LXMFBot:
                 next_announce = int(time.time()) + self.announce_time
                 af.write(str(next_announce))
             self.local.announce()
-            RNS.log(f"Announcement sent, next announce in {self.announce_time} seconds", RNS.LOG_INFO)
+            RNS.log(
+                f"Announcement sent, next announce in {self.announce_time} seconds",
+                RNS.LOG_INFO,
+            )
 
-    def send(self, destination: str, message: str, title: str = "Reply", lxmf_fields: Optional[dict] = None):
+    def send(
+        self,
+        destination: str,
+        message: str,
+        title: str = "Reply",
+        lxmf_fields: dict | None = None,
+        stamp_cost: int | None = None,
+    ):
         """Send a message to a destination, optionally with custom LXMF fields.
 
         Args:
@@ -387,8 +467,18 @@ class LXMFBot:
             message: The message content (will be utf-8 encoded).
             title: The message title (optional, will be utf-8 encoded).
             lxmf_fields: Optional dictionary of LXMF fields.
+            stamp_cost: Optional stamp cost override. If None, uses config.stamp_cost.
 
         """
+        if self.config.test_mode:
+            # In test mode, just queue a mock message
+            mock_message = SimpleNamespace()
+            mock_message.content = message.encode("utf-8")
+            mock_message.title = title.encode("utf-8") if title else None
+            mock_message.fields = lxmf_fields
+            self.queue.put(mock_message)
+            return
+
         try:
             dest_hash_bytes = bytes.fromhex(destination)
         except ValueError:
@@ -413,44 +503,129 @@ class LXMFBot:
             return
 
         lxmf_destination_obj = RNS.Destination(
-            identity_instance, RNS.Destination.OUT, RNS.Destination.SINGLE, "lxmf", "delivery"
+            identity_instance,
+            RNS.Destination.OUT,
+            RNS.Destination.SINGLE,
+            "lxmf",
+            "delivery",
         )
 
         # Ensure message and title are bytes
-        message_bytes = message.encode('utf-8')
-        title_bytes = title.encode('utf-8') if title else None
+        message_bytes = message.encode("utf-8")
+        title_bytes = title.encode("utf-8") if title else None
+
+        # Determine delivery method based on retry count
+        attempts = self.delivery_attempts.get(destination, 0)
+        max_retries = self.config.direct_delivery_retries
+
+        if attempts >= max_retries and self.config.propagation_fallback_enabled:
+            desired_method = LXMessage.PROPAGATED
+            RNS.log(
+                f"Using propagation for {destination} after {attempts} failed direct attempts",
+                RNS.LOG_INFO,
+            )
+        else:
+            desired_method = LXMessage.DIRECT
+
+        # Use provided stamp_cost or fall back to config
+        final_stamp_cost = (
+            stamp_cost if stamp_cost is not None else self.config.stamp_cost
+        )
 
         lxm = LXMessage(
             lxmf_destination_obj,
             self.local,
             message_bytes,
             title=title_bytes,
-            desired_method=LXMessage.DIRECT,
-            fields=lxmf_fields
+            desired_method=desired_method,
+            fields=lxmf_fields,
+            stamp_cost=final_stamp_cost,
         )
-        lxm.try_propagation_on_fail = True
-        self.queue.put(lxm)
-        RNS.log(f"Message queued for {destination}", RNS.LOG_DEBUG)
 
-    def send_with_attachment(self, destination: str, message: str, attachment: Attachment, title: str = "Reply"):
+        # Track attempts for this destination
+        self.delivery_attempts[destination] = attempts + 1
+
+        # Register callbacks to reset counter on success or increment on failure
+        def on_delivery_success(_message):
+            if destination in self.delivery_attempts:
+                self.delivery_attempts[destination] = 0
+                RNS.log(
+                    f"Delivery successful to {destination}, reset retry counter",
+                    RNS.LOG_DEBUG,
+                )
+
+        def on_delivery_failure(_message):
+            current_attempts = self.delivery_attempts.get(destination, 0)
+            if current_attempts < max_retries:
+                RNS.log(
+                    f"Delivery failed to {destination}, attempt {current_attempts}/{max_retries}",
+                    RNS.LOG_WARNING,
+                )
+            else:
+                RNS.log(
+                    f"Delivery failed to {destination} after {current_attempts} attempts",
+                    RNS.LOG_ERROR,
+                )
+
+        lxm.register_delivery_callback(on_delivery_success)
+        lxm.register_failed_callback(on_delivery_failure)
+
+        # Sign the message (pass-through for LXMF's built-in signing)
+        lxm = sign_outgoing_message(self, lxm)
+
+        # Set propagation fallback if enabled and we're trying direct first
+        if (
+            desired_method == LXMessage.DIRECT
+            and self.config.propagation_fallback_enabled
+        ):
+            lxm.try_propagation_on_fail = True
+
+        self.queue.put(lxm)
+        RNS.log(
+            f"Message queued for {destination} (method: {desired_method})",
+            RNS.LOG_DEBUG,
+        )
+
+    def send_with_attachment(
+        self,
+        destination: str,
+        message: str,
+        attachment: Attachment,
+        title: str = "Reply",
+        stamp_cost: int | None = None,
+    ):
         """Send a message with an attachment to a destination.
+
+        Args:
+            destination: The destination hash.
+            message: The message content.
+            attachment: The attachment to send.
+            title: The message title.
+            stamp_cost: Optional stamp cost override.
+
         """
         attachment_specific_fields = pack_attachment(attachment)
-        self.send(destination, message, title=title, lxmf_fields=attachment_specific_fields)
+        self.send(
+            destination,
+            message,
+            title=title,
+            lxmf_fields=attachment_specific_fields,
+            stamp_cost=stamp_cost,
+        )
 
     def run(self, delay=10):
         """Run the bot"""
+        self.scheduler.start()  # Start the scheduler
         try:
             while True:
                 for _i in list(self.queue.queue):
                     lxm = self.queue.get()
                     self.router.handle_outbound(lxm)
 
-                self._announce()
                 time.sleep(delay)
 
         except KeyboardInterrupt:
-            self.transport.cleanup()
+            self.cleanup()  # Call cleanup on KeyboardInterrupt
 
     def received(self, function):
         """Decorator for registering delivery callbacks.
@@ -463,7 +638,10 @@ class LXMFBot:
         return function
 
     def request_page(
-        self, destination_hash: str, page_path: str, field_data: Optional[dict] = None
+        self,
+        destination_hash: str,
+        page_path: str,
+        field_data: dict | None = None,
     ) -> dict:
         """Request a page from a destination.
 
@@ -487,13 +665,26 @@ class LXMFBot:
         """Clean up resources."""
         self.transport.cleanup()
         self.thread_pool.shutdown(wait=True)
+        self.scheduler.stop()  # Stop the scheduler
 
     def on_first_message(self):
         """Decorator for registering first message handlers"""
+
         def decorator(func):
             """Registers a function to be called on the first message from a sender."""
             self.first_message_handlers.append(func)
             return func
+
+        return decorator
+
+    def on_message(self):
+        """Decorator for registering message handlers"""
+
+        def decorator(func):
+            """Registers a function to be called on every message."""
+            self.message_handlers.append(func)
+            return func
+
         return decorator
 
     def validate(self) -> str:
