@@ -8,4 +8,4 @@ from .echo_bot import EchoBot
 from .note_bot import NoteBot
 from .reminder_bot import ReminderBot
 
-__all__ = ["EchoBot", "ReminderBot", "NoteBot", "CogTestBot"]
+__all__ = ["CogTestBot", "EchoBot", "NoteBot", "ReminderBot"]
