@@ -9,8 +9,8 @@ handlers.
 
 import logging
 import time
+from collections.abc import Callable
 from dataclasses import dataclass
-from typing import Callable, Optional
 
 import RNS
 
@@ -28,14 +28,13 @@ class PathInfo:
 
     """
 
-    next_hop: Optional[bytes]
+    next_hop: bytes | None
     hops: int
     updated_at: int
 
 
 class Transport:
-    """Manages network transport for LXMFy, handling links and paths.
-    """
+    """Manages network transport for LXMFy, handling links and paths."""
 
     def __init__(self, storage):
         """Initializes the Transport instance.
@@ -185,7 +184,7 @@ class Transport:
                 link.teardown()
 
         self.cached_links = {
-            hash: link
-            for hash, link in self.cached_links.items()
+            dest_hash: link
+            for dest_hash, link in self.cached_links.items()
             if link.status == RNS.Link.ACTIVE
         }
